JsDoc Reference - Index

Generated by JsDoc Toolkit 2.4.0 on Wed Dec 15 2010 21:57:11 GMT-0000 (GMT)
HTML template: Codeview

# Class Index

- ## _global_

- ## ColReorder

  ColReorder

- ## ColReorder#dom

  Common and useful DOM elements for the class instance

- ## ColReorder#s

  Settings object which contains customisable information for ColReorder instance

- ## ColReorder#s.mouse

  Information used for the mouse drag